@@ -8,7 +8,7 @@ y_loc=40
 led_vis=0
 menu_vis=0
 blinker_stat=0
-mem6_stat=True
+mem6_stat=False
 mem7_stat=True
 mem8_stat=True
 def led(event):
@@ -143,6 +143,7 @@ class lfocusplug(hildondesktop.StatusMenuItem):
 				self.maintimer = gobject.timeout_add(1000, self.rled_off)
 		if (self.button6.get_active()):
 				stat=self.button3.get_active()
+				self.button6.set_active(False)
 				self.maintimer = gobject.timeout_add(1000, self.led_mem,stat)
 	def signal_filter(self,lfocus_string):
 		global led_vis
@@ -252,7 +253,7 @@ class lfocusplug(hildondesktop.StatusMenuItem):
 		table.attach(self.button6, 0, 1, 2, 3)
 		table.attach(self.button7, 1, 2, 2, 3)
 		table.attach(self.button8, 2, 3, 2, 3)
-		self.button6.set_active(mem7_stat)
+		self.button6.set_active(mem6_stat)
 		self.button7.set_active(mem7_stat)
 		self.button8.set_active(mem8_stat)
 		def mem6(self):
